from django.contrib import admin

from .models import Caller, Call, Cron


class MetadataModelAdmin:
    list_display = [
        'status',
        'spooled',
        'started',
        'ended',
        'created',
    ]


@admin.register(Caller)
class CallerAdmin(admin.ModelAdmin):
    list_display = [
        'id',
        'callback',
        'spooler',
    ] + MetadataModelAdmin.list_display

    search_fields = [
        'pk',
        'kwargs',
    ]

    list_filter = [
        'status',
        'spooler',
        'priority',
        'callback',
    ]


@admin.register(Call)
class CallAdmin(admin.ModelAdmin):
    list_display = [
        'id',
        'caller',
    ] + MetadataModelAdmin.list_display

    list_filter = [
        'status',
        'caller__callback',
    ]

    search_fields = [
        'caller__callback',
        'caller__kwargs',
        'caller__pk',
    ]


@admin.register(Cron)
class CronAdmin(admin.ModelAdmin):
    list_display = [
        'minute',
        'hour',
        'day',
        'month',
        'weekday',
        'caller',
    ]
    readonly_fields = [
        'caller',
        'minute',
        'hour',
        'day',
        'month',
        'weekday',
    ]



from django.contrib import admin

from crudlfap import shortcuts as crudlfap

from django.conf import settings
from django.urls import include, path

urlpatterns = [
    path('admin/', admin.site.urls),
    crudlfap.site.urlpattern,
]

if 'debug_toolbar' in settings.INSTALLED_APPS and settings.DEBUG:
    import debug_toolbar
    urlpatterns += [
        path('__debug__/', include(debug_toolbar.urls)),
    ]



from django import apps

try:
    import uwsgi
except ImportError:
    uwsgi = None


class DjcallConfig(apps.AppConfig):
    name = 'djcall'

    def ready(self):
        if not uwsgi:
            return
        from .models import setup
        try:
            setup()
        except Exception as e:
            print(e)
            print('Could not register cron objects to uWSGI')



# flake8: noqa: D*
import os
from crudlfap.settings import *

DEBUG = True

ROOT_URLCONF = 'djcall_example.urls'

INSTALLED_APPS += ['djcall']

STATIC_ROOT = 'static'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql',
        'USER': os.getenv('POSTGRES_USER', os.getenv('USER')),
        'NAME': os.getenv('POSTGRES_DB', 'djcall'),
        'PASSWORD': os.getenv('POSTGRES_PASSWORD', None),
        'HOST': os.getenv('POSTGRES_HOST', None),
    }
}



# Generated by Django 2.2.12 on 2020-04-30 00:10

import django.contrib.postgres.fields.jsonb
from django.db import migrations
import jsonlight


def convert_kwargs(apps, schema_editor):
    Caller = apps.get_model('djcall', 'Caller')
    for caller in Caller.objects.all():
        caller.kwargs = jsonlight.dumps(caller.old_kwargs)
        caller.save()


class Migration(migrations.Migration):

    dependencies = [
        ('djcall', '0003_status_canceled'),
    ]

    operations = [
        migrations.RenameField(
            model_name='caller',
            old_name='kwargs',
            new_name='old_kwargs',
        ),
        migrations.AddField(
            model_name='caller',
            name='kwargs',
            field=django.contrib.postgres.fields.jsonb.JSONField(null=True),
        ),
        migrations.RunPython(convert_kwargs),
    ]
